@@ -64,6 +64,11 @@ class Keepalived(object):
         if init_system == consts.INIT_SYSTEMD:
             template = SYSTEMD_TEMPLATE
             init_enable_cmd = "systemctl enable octavia-keepalived"
+
+            # Render and install the network namespace systemd service
+            util.install_netns_systemd_service()
+            util.run_systemctl_command(
+                consts.ENABLE, consts.AMP_NETNS_SVC_PREFIX)
         elif init_system == consts.INIT_UPSTART:
             template = UPSTART_TEMPLATE
         elif init_system == consts.INIT_SYSVINIT:
@@ -86,7 +91,8 @@ class Keepalived(object):
                     keepalived_cmd=consts.KEEPALIVED_CMD,
                     keepalived_cfg=util.keepalived_cfg_path(),
                     keepalived_log=util.keepalived_log_path(),
-                    amphora_nsname=consts.AMPHORA_NAMESPACE
+                    amphora_nsname=consts.AMPHORA_NAMESPACE,
+                    amphora_netns=consts.AMP_NETNS_SVC_PREFIX
                 )
                 text_file.write(text)
 
@@ -128,6 +134,20 @@ class Keepalived(object):
                 message='Invalid Request',
                 details="Unknown action: {0}".format(action)), status=400)
 
+        if action == consts.AMP_ACTION_START:
+            keepalived_pid_path = util.keepalived_pid_path()
+            try:
+                # Is there a pid file for keepalived?
+                with open(keepalived_pid_path, 'r') as pid_file:
+                    pid = int(pid_file.readline())
+                os.kill(pid, 0)
+
+                # If we got here, it means the keepalived process is running.
+                # We should reload it instead of trying to start it again.
+                action = consts.AMP_ACTION_RELOAD
+            except (IOError, OSError):
+                pass
+
         cmd = ("/usr/sbin/service octavia-keepalived {action}".format(
             action=action))
 
