@@ -28,9 +28,8 @@ from octavia.api.v1.types import pool as pool_types
 from octavia.common import constants
 from octavia.common import data_models
 from octavia.common import exceptions
+from octavia.db import api as db_api
 from octavia.db import prepare as db_prepare
-from octavia.i18n import _LI
-
 
 LOG = logging.getLogger(__name__)
 
@@ -50,18 +49,23 @@ class PoolsController(base.BaseController):
         db_pool = self._get_db_pool(context.session, id)
         return self._convert_db_to_type(db_pool, pool_types.PoolResponse)
 
-    @wsme_pecan.wsexpose([pool_types.PoolResponse], wtypes.text)
+    @wsme_pecan.wsexpose([pool_types.PoolResponse], wtypes.text,
+                         ignore_extra_args=True)
     def get_all(self, listener_id=None):
         """Lists all pools on a listener or loadbalancer."""
-        context = pecan.request.context.get('octavia_context')
+        pcontext = pecan.request.context
+        context = pcontext.get('octavia_context')
+
         if listener_id is not None:
             self.listener_id = listener_id
         if self.listener_id:
             pools = self._get_db_listener(context.session,
                                           self.listener_id).pools
         else:
-            pools = self.repositories.pool.get_all(
-                context.session, load_balancer_id=self.load_balancer_id)
+            pools, _ = self.repositories.pool.get_all(
+                context.session,
+                pagination_helper=pcontext.get(constants.PAGINATION_HELPER),
+                load_balancer_id=self.load_balancer_id)
         return self._convert_db_to_type(pools, [pool_types.PoolResponse])
 
     def _get_affected_listener_ids(self, session, pool=None):
@@ -81,41 +85,34 @@ class PoolsController(base.BaseController):
                 session, self.load_balancer_id,
                 constants.PENDING_UPDATE, constants.PENDING_UPDATE,
                 listener_ids=self._get_affected_listener_ids(session, pool)):
-            LOG.info(_LI("Pool cannot be created or modified because the Load "
-                         "Balancer is in an immutable state"))
+            LOG.info("Pool cannot be created or modified because the Load "
+                     "Balancer is in an immutable state")
             lb_repo = self.repositories.load_balancer
             db_lb = lb_repo.get(session, id=self.load_balancer_id)
             raise exceptions.ImmutableObject(resource=db_lb._name(),
                                              id=self.load_balancer_id)
 
-    def _validate_create_pool(self, session, pool_dict):
+    def _validate_create_pool(self, lock_session, pool_dict):
         """Validate creating pool on load balancer.
 
         Update database for load balancer and (optional) listener based on
         provisioning status.
         """
         try:
-            db_pool = self.repositories.create_pool_on_load_balancer(
-                session, pool_dict, listener_id=self.listener_id)
+            return self.repositories.create_pool_on_load_balancer(
+                lock_session, pool_dict, listener_id=self.listener_id)
         except odb_exceptions.DBDuplicateEntry as de:
             if ['id'] == de.columns:
                 raise exceptions.IDAlreadyExists()
         except odb_exceptions.DBError:
-            # Setting LB and Listener back to active because this is just a
-            # validation failure
-            for listener_id in self._get_affected_listener_ids(session):
-                self.repositories.listener.update(
-                    session, listener_id, provisioning_status=constants.ACTIVE)
-            self.repositories.load_balancer.update(
-                session, self.load_balancer_id,
-                provisioning_status=constants.ACTIVE)
             # TODO(blogan): will have to do separate validation protocol
             # before creation or update since the exception messages
             # do not give any information as to what constraint failed
             raise exceptions.InvalidOption(value='', option='')
+
+    def _send_pool_to_handler(self, session, db_pool):
         try:
-            LOG.info(_LI("Sending Creation of Pool %s to handler"),
-                     db_pool.id)
+            LOG.info("Sending Creation of Pool %s to handler", db_pool.id)
             self.handler.create(db_pool)
         except Exception:
             for listener_id in self._get_affected_listener_ids(session):
@@ -138,21 +135,44 @@ class PoolsController(base.BaseController):
         # For some API requests the listener_id will be passed in the
         # pool_dict:
         context = pecan.request.context.get('octavia_context')
-        pool_dict = db_prepare.create_pool(pool.to_dict(render_unsets=True))
-        if 'listener_id' in pool_dict:
-            if pool_dict['listener_id'] is not None:
-                self.listener_id = pool_dict.pop('listener_id')
-            else:
-                del pool_dict['listener_id']
-        if self.listener_id and self.repositories.listener.has_default_pool(
-                context.session, self.listener_id):
-            raise exceptions.DuplicatePoolEntry()
-        self._test_lb_and_listener_statuses(context.session)
 
-        pool_dict['operating_status'] = constants.OFFLINE
-        pool_dict['load_balancer_id'] = self.load_balancer_id
+        pool.project_id = self._get_lb_project_id(context.session,
+                                                  self.load_balancer_id)
 
-        return self._validate_create_pool(context.session, pool_dict)
+        lock_session = db_api.get_session(autocommit=False)
+        if self.repositories.check_quota_met(
+                context.session,
+                lock_session,
+                data_models.Pool,
+                pool.project_id):
+            lock_session.rollback()
+            raise exceptions.QuotaException(
+                resource=data_models.Pool._name())
+
+        try:
+            pool_dict = db_prepare.create_pool(
+                pool.to_dict(render_unsets=True))
+            if 'listener_id' in pool_dict:
+                if pool_dict['listener_id'] is not None:
+                    self.listener_id = pool_dict.pop('listener_id')
+                else:
+                    del pool_dict['listener_id']
+            listener_repo = self.repositories.listener
+            if self.listener_id and listener_repo.has_default_pool(
+                    lock_session, self.listener_id):
+                raise exceptions.DuplicatePoolEntry()
+            self._test_lb_and_listener_statuses(lock_session)
+
+            pool_dict['operating_status'] = constants.OFFLINE
+            pool_dict['load_balancer_id'] = self.load_balancer_id
+
+            db_pool = self._validate_create_pool(lock_session, pool_dict)
+            lock_session.commit()
+        except Exception:
+            with excutils.save_and_reraise_exception():
+                lock_session.rollback()
+
+        return self._send_pool_to_handler(context.session, db_pool)
 
     @wsme_pecan.wsexpose(pool_types.PoolResponse, wtypes.text,
                          body=pool_types.PoolPUT, status_code=202)
@@ -163,7 +183,7 @@ class PoolsController(base.BaseController):
         self._test_lb_and_listener_statuses(context.session, pool=db_pool)
 
         try:
-            LOG.info(_LI("Sending Update of Pool %s to handler"), id)
+            LOG.info("Sending Update of Pool %s to handler", id)
             self.handler.update(db_pool, pool)
         except Exception:
             with excutils.save_and_reraise_exception(reraise=False):
@@ -188,8 +208,7 @@ class PoolsController(base.BaseController):
         self._test_lb_and_listener_statuses(context.session, pool=db_pool)
 
         try:
-            LOG.info(_LI("Sending Deletion of Pool %s to handler"),
-                     db_pool.id)
+            LOG.info("Sending Deletion of Pool %s to handler", db_pool.id)
             self.handler.delete(db_pool)
         except Exception:
             with excutils.save_and_reraise_exception(reraise=False):
@@ -217,7 +236,7 @@ class PoolsController(base.BaseController):
             remainder = remainder[1:]
             db_pool = self.repositories.pool.get(context.session, id=pool_id)
             if not db_pool:
-                LOG.info(_LI("Pool %s not found."), pool_id)
+                LOG.info("Pool %s not found.", pool_id)
                 raise exceptions.NotFound(resource=data_models.Pool._name(),
                                           id=pool_id)
             if controller == 'members':
