@@ -12,8 +12,6 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import logging
-
 from oslo_config import cfg
 import pecan
 from wsme import types as wtypes
@@ -21,10 +19,11 @@ from wsmeext import pecan as wsme_pecan
 
 from octavia.api.v1.controllers import base
 from octavia.api.v1.types import quotas as quota_types
+from octavia.common import constants
+from octavia.common import exceptions
 
 CONF = cfg.CONF
 CONF.import_group('quotas', 'octavia.common.config')
-LOG = logging.getLogger(__name__)
 
 
 class QuotasController(base.BaseController):
@@ -43,7 +42,7 @@ class QuotasController(base.BaseController):
     def get_all(self):
         """List all non-default quotas."""
         context = pecan.request.context.get('octavia_context')
-        db_quotas = self.repositories.quotas.get_all(context.session)
+        db_quotas, _ = self.repositories.quotas.get_all(context.session)
         quotas = quota_types.QuotaAllResponse.from_data_model(db_quotas)
         return quotas
 
@@ -52,6 +51,18 @@ class QuotasController(base.BaseController):
     def put(self, project_id, quotas):
         """Update any or all quotas for a project."""
         context = pecan.request.context.get('octavia_context')
+
+        new_project_id = context.project_id
+        if context.is_admin or (CONF.api_settings.auth_strategy ==
+                                constants.NOAUTH):
+            if project_id:
+                new_project_id = project_id
+
+        if not new_project_id:
+            raise exceptions.MissingAPIProjectID()
+
+        project_id = new_project_id
+
         quotas_dict = quotas.to_dict()
         self.repositories.quotas.update(context.session, project_id,
                                         **quotas_dict)
