@@ -101,6 +101,9 @@ class HealthMonitorController(base.BaseController):
         # mutable
         pool = self.repositories.pool.get(session, id=hm.pool_id)
         load_balancer_id = pool.load_balancer_id
+        # Check the parent is not locked for some reason (ERROR, etc.)
+        if pool.provisioning_status not in constants.MUTABLE_STATUSES:
+            raise exceptions.ImmutableObject(resource='Pool', id=hm.pool_id)
         if not self.repositories.test_and_set_lb_and_listeners_prov_status(
                 session, load_balancer_id,
                 constants.PENDING_UPDATE, constants.PENDING_UPDATE,
@@ -177,7 +180,8 @@ class HealthMonitorController(base.BaseController):
                     lock_session,
                     data_models.HealthMonitor,
                     health_monitor.project_id):
-                raise exceptions.QuotaException
+                raise exceptions.QuotaException(
+                    resource=data_models.HealthMonitor._name())
 
             hm_dict = db_prepare.create_health_monitor(
                 health_monitor.to_dict(render_unsets=True))
