@@ -14,17 +14,19 @@
 #    under the License.
 
 import base64
+import hashlib
 
 from cryptography.hazmat import backends
 from cryptography.hazmat.primitives import serialization
 from cryptography import x509
+from oslo_context import context as oslo_context
 from oslo_log import log as logging
 from pyasn1.codec.der import decoder as der_decoder
 from pyasn1.codec.der import encoder as der_encoder
 from pyasn1_modules import rfc2315
 import six
 
-from octavia.common import data_models as data_models
+from octavia.common import data_models
 import octavia.common.exceptions as exceptions
 
 X509_BEG = b'-----BEGIN CERTIFICATE-----'
@@ -49,10 +51,10 @@ def validate_cert(certificate, private_key=None,
     :returns: boolean
     """
     cert = _get_x509_from_pem_bytes(certificate)
-    if intermediates:
-        for imd in get_intermediates_pems(intermediates):
-            # Loading the certificates validates them
-            pass
+    if intermediates and not isinstance(intermediates, list):
+        # If the intermediates are in a list, then they are already loaded.
+        # Load the certificates to validate them, if they weren't already.
+        list(get_intermediates_pems(intermediates))
     if private_key:
         pkey = _read_private_key(private_key,
                                  passphrase=private_key_passphrase)
@@ -70,7 +72,7 @@ def _read_private_key(private_key_pem, passphrase=None):
     :param passphrase: Optional passphrase needed to decrypt the private key
     :returns: a RSAPrivatekey object
     """
-    if passphrase:
+    if passphrase and type(passphrase) == six.text_type:
         passphrase = passphrase.encode("utf-8")
     if type(private_key_pem) == six.text_type:
         private_key_pem = private_key_pem.encode('utf-8')
@@ -319,52 +321,61 @@ def _get_x509_from_der_bytes(certificate_der):
 
 
 def build_pem(tls_container):
-        """Concatenate TLS container fields to create a PEM
+    """Concatenate TLS container fields to create a PEM
 
-        encoded certificate file
+    encoded certificate file
 
-        :param tls_container: Object container TLS certificates
-        :returns: Pem encoded certificate file
-        """
-        pem = [tls_container.certificate, tls_container.private_key]
-        if tls_container.intermediates:
-            pem.extend(tls_container.intermediates[:])
-        return b'\n'.join(pem) + b'\n'
+    :param tls_container: Object container TLS certificates
+    :returns: Pem encoded certificate file
+    """
+    pem = [tls_container.certificate, tls_container.private_key]
+    if tls_container.intermediates:
+        pem.extend(tls_container.intermediates[:])
+    return b'\n'.join(pem) + b'\n'
 
 
-def load_certificates_data(cert_mngr, listener):
-        """Load TLS certificate data from the listener.
+def load_certificate_data(cert_mngr, cert_ref, context):
+    """Load TLS certificate data."""
+    return _map_cert_tls_container(
+        cert_mngr.get_cert(context, cert_ref, check_only=True))
 
-        return TLS_CERT and SNI_CERTS
-        """
-        tls_cert = None
-        sni_certs = []
 
-        if listener.tls_certificate_id:
-            tls_cert = _map_cert_tls_container(
-                cert_mngr.get_cert(listener.project_id,
-                                   listener.tls_certificate_id,
-                                   check_only=True))
-        if listener.sni_containers:
-            for sni_cont in listener.sni_containers:
-                cert_container = _map_cert_tls_container(
-                    cert_mngr.get_cert(listener.project_id,
-                                       sni_cont.tls_container_id,
-                                       check_only=True))
-                sni_certs.append(cert_container)
-        return {'tls_cert': tls_cert, 'sni_certs': sni_certs}
+def load_certificates_data(cert_mngr, listener, context=None):
+    """Load TLS certificate data from the listener.
+
+    return TLS_CERT and SNI_CERTS
+    """
+    tls_cert = None
+    sni_certs = []
+    if not context:
+        context = oslo_context.RequestContext(project_id=listener.project_id)
+
+    if listener.tls_certificate_id:
+        tls_cert = load_certificate_data(
+            cert_mngr, listener.tls_certificate_id, context)
+
+    if listener.sni_containers:
+        for sni_cont in listener.sni_containers:
+            cert_container = load_certificate_data(
+                cert_mngr, sni_cont.tls_container_id, context)
+            sni_certs.append(cert_container)
+    return {'tls_cert': tls_cert, 'sni_certs': sni_certs}
 
 
 def _map_cert_tls_container(cert):
-        return data_models.TLSContainer(
-            primary_cn=get_primary_cn(cert),
-            private_key=prepare_private_key(
-                cert.get_private_key(),
-                cert.get_private_key_passphrase()),
-            certificate=cert.get_certificate(),
-            intermediates=cert.get_intermediates())
+    return data_models.TLSContainer(
+        # TODO(rm_work): applying nosec here because this is not intended to be
+        # secure, it's just a way to get a consistent ID. Changing this would
+        # break backwards compatibility with existing loadbalancers.
+        id=hashlib.sha1(cert.get_certificate()).hexdigest(),  # nosec
+        primary_cn=get_primary_cn(cert),
+        private_key=prepare_private_key(
+            cert.get_private_key(),
+            cert.get_private_key_passphrase()),
+        certificate=cert.get_certificate(),
+        intermediates=cert.get_intermediates())
 
 
 def get_primary_cn(tls_cert):
-        """Returns primary CN for Certificate."""
-        return get_host_names(tls_cert.get_certificate())['cn']
+    """Returns primary CN for Certificate."""
+    return get_host_names(tls_cert.get_certificate())['cn']
